==> solstice-1.3.1%2B1.21.1-sources.jar: me/alexdevs/solstice/modules/mute/commands/UnmuteCommand.java <==
package me.alexdevs.solstice.modules.mute.commands;

import com.mojang.authlib.GameProfile;
import com.mojang.brigadier.builder.LiteralArgumentBuilder;
import me.alexdevs.solstice.Solstice;
import me.alexdevs.solstice.api.module.ModCommand;
import me.alexdevs.solstice.modules.mute.MuteModule;
import net.minecraft.class_2168;
import net.minecraft.class_2191;
import net.minecraft.class_2561;
import java.util.List;

import static net.minecraft.class_2170.method_9244;
import static net.minecraft.class_2170.method_9247;

public class UnmuteCommand extends ModCommand<MuteModule> {
    public UnmuteCommand(MuteModule module) {
        super(module);
    }

    @Override
    public List<String> getNames() {
        return List.of("unmute");
    }

    @Override
    public LiteralArgumentBuilder<class_2168> command(String name) {
        return method_9247(name)
                .requires(require(2))
                .then(method_9244("targets", class_2191.method_9329())
                        .executes(context -> {
                            var targets = class_2191.method_9330(context, "targets");

                            var names = targets.stream().map(GameProfile::getName).toArray(String[]::new);

                            targets.forEach(profile -> {
                                var playerData = module.getPlayerData(profile.getId());
                                playerData.muted = false;
                            });

                            Solstice.playerData.saveAll();

                            context.getSource().method_9226(() -> class_2561.method_43470("Unmuted " + String.join(", ", names)), true);

                            return 1;
                        }));
    }
}

==> solstice-1.9.2%2B1.21.1-sources.jar: me/alexdevs/solstice/modules/mute/commands/UnmuteCommand.java <==
package me.alexdevs.solstice.modules.mute.commands;

import com.mojang.brigadier.builder.LiteralArgumentBuilder;
import me.alexdevs.solstice.Solstice;
import me.alexdevs.solstice.api.module.ModCommand;
import me.alexdevs.solstice.modules.mute.MuteModule;
import net.minecraft.class_2168;
import net.minecraft.class_2191;
import net.minecraft.class_2561;
import java.util.List;
import java.util.Map;

import static net.minecraft.class_2170.method_9244;
import static net.minecraft.class_2170.method_9247;

public class UnmuteCommand extends ModCommand<MuteModule> {
    public UnmuteCommand(MuteModule module) {
        super(module);
    }

    @Override
    public List<String> getNames() {
        return List.of("unmute");
    }

    @Override
    public LiteralArgumentBuilder<class_2168> command(String name) {
        return method_9247(name)
                .requires(require(2))
                .then(method_9244("targets", class_2191.method_9329())
                        .executes(context -> {
                            var targets = class_2191.method_9330(context, "targets");

                            targets.forEach(profile -> {
                                var playerData = module.getPlayerData(profile.getId());
                                playerData.muted = false;
                                playerData.mutedUntil = null;
                            });

                            Solstice.playerData.saveAll();

                            String localeKey;
                            if (targets.size() == 1) {
                                localeKey = "unmuted";
                            } else {
                                localeKey = "unmutedMultiple";
                            }

                            var placeholders = Map.of(
                                    "count", class_2561.method_30163(String.valueOf(targets.size())),
                                    "player", class_2561.method_30163(targets.stream().findFirst().get().getName())
                            );

                            context.getSource().method_9226(() -> module.locale().get(localeKey, placeholders), true);

                            return 1;
                        }));
    }
}
